//in Qt5 I get many deprcation warnings but the code still needs to be compatible with qt4 so this is thougt to be useful
#ifndef XLEDEPR_H
#define XLEDEPR_H 1
#if (QT_VERSION >= 0x050e00)
#define skipEmptyParts Qt::SkipEmptyParts
#define keepEmptyParts Qt::KeepEmptyParts
#else
#define skipEmptyParts QString::SkipEmptyParts
#define keepEmptyParts QString::KeepEmptyParts
#endif

#endif
